@@ -1,7 +1,8 @@
 from qtpy.QtCore import QObject, Signal, Slot, Property, QUrl
 from qtpy.QtWebEngineWidgets import * 
 from qtpy.QtWebChannel import *
-import os
+
+from pathlib import Path
 import json
 
 
@@ -75,21 +76,27 @@ class EditorBridge(BaseBridge):
     theme = Property(str, fget=getTheme, fset=setTheme, notify=themeChanged)
 
 
+index = Path(__file__).parent / "index.html"
+
+with open(index) as f:
+    raw_html = f.read()
+
 class MonacoWidget(QWebEngineView):
     textChanged = Signal(str)
 
     def __init__(self, parent=None):
         super().__init__(parent=parent)
 
-        CURRENT_DIR = os.path.dirname(os.path.realpath(__file__))
-        filename = os.path.join(CURRENT_DIR, "index.html")
-        self.load(QUrl.fromLocalFile(filename))
+        html = raw_html.replace('width:400px;', f'width:{self.size().width()}px;')
+        html = raw_html.replace('height:400px;', f'height:{self.size().height()}px;')
 
-        channel = QWebChannel(self)
-        self.page().setWebChannel(channel)
+        self.setHtml(html, QUrl.fromLocalFile(Path(__file__).parent / "index.html") )
 
+        self._channel = QWebChannel(self)
         self._bridge = EditorBridge()
-        channel.registerObject("bridge", self._bridge)
+
+        self.page().setWebChannel(self._channel)
+        self._channel.registerObject("bridge", self._bridge)
 
         self._bridge.valueChanged.connect(lambda: self.textChanged.emit(self._bridge.value))
 
